@@ -1,15 +1,13 @@
+from venmo_api import string_to_timestamp, User, BaseModel, JSONSchema
 from enum import Enum
 
-from venmo_api import string_to_timestamp, User, BaseModel
-from venmo_api import JSONSchema
-
 
 class Payment(BaseModel):
 
     def __init__(self, id_, actor, target, action, amount, audience, date_created, date_reminded, date_completed,
-                 note, status):
+                 note, status, json=None):
         """
-        Create a Payment object
+        Payment model
         :param id_:
         :param actor:
         :param target:
@@ -21,6 +19,7 @@ class Payment(BaseModel):
         :param date_completed:
         :param note:
         :param status:
+        :param json:
         """
         super().__init__()
         self.id = id_
@@ -34,6 +33,7 @@ class Payment(BaseModel):
         self.date_completed = date_completed
         self.note = note
         self.status = status
+        self._json = json
 
     @classmethod
     def from_json(cls, json):
@@ -58,7 +58,8 @@ class Payment(BaseModel):
             date_reminded=string_to_timestamp(parser.get_date_reminded()),
             date_completed=string_to_timestamp(parser.get_date_completed()),
             note=parser.get_note(),
-            status=PaymentStatus(parser.get_status())
+            status=PaymentStatus(parser.get_status()),
+            json=json
         )
 
 
@@ -66,3 +67,4 @@ class PaymentStatus(Enum):
     SETTLED = 'settled'
     CANCELLED = 'cancelled'
     PENDING = 'pending'
+    FAILED = 'failed'
